RUser

Struct RUser 

pub struct RUser {
    pub id: String,
    pub token: String,
}
日本語

actix-web / axum から抽出される認証済みユーザーコンテキストです。

抽出が成功した場合:

  • idRTokenManager::login に渡したユーザー ID
  • token はリクエストに含まれていた token の生文字列

token は Authorization header から読み取ります。次の形式に対応します:

  • Authorization: <token>
  • Authorization: Bearer <token>

English

An authenticated request context extracted from actix-web / axum.

If extraction succeeds, id is the user id previously passed to RTokenManager::login, and token is the original token from the request.

The token is read from Authorization header. Both of the following formats are accepted:

  • Authorization: <token>
  • Authorization: Bearer <token>

Fields

id: String

日本語

token に紐づくユーザー ID。

English

The user id associated with the token.

token: String

日本語

リクエストに含まれていた token の生文字列。

English

The raw token string from the request.