RUser

Struct RUser 

pub struct RUser {
    pub id: String,
    pub token: String,
}
An authenticated request context extracted from actix-web.

If extraction succeeds, id is the user id previously passed to RTokenManager::login, and token is the original token from the request.

The token is read from Authorization header. Both of the following formats are accepted:

  • Authorization: <token>
  • Authorization: Bearer <token>

繁體中文

由 actix-web 自動抽取的已驗證使用者上下文。

Extractor 成功時:

  • id 會是先前傳給 RTokenManager::login 的使用者 id
  • token 會是請求中帶來的 token 原文

token 會從 Authorization header 讀取,支援以下格式:

  • Authorization: <token>
  • Authorization: Bearer <token>

Fields

id: String

The user id associated with the token.

繁體中文

與 token 綁定的使用者 id。

token: String

The raw token string from the request.

繁體中文

來自請求的 token 字串原文。